## 0.0.36

This new version includes a refactor of the CLI to improve code readability and understanding.

### New Features

No new features were added in this version.

### Bug Fixes

No bug fixes were made in this version.

### Refactors

- The `commit_message` function in `llamabot/cli/git.py` has been renamed to `commit` to better reflect its purpose of committing staged changes (ae7b10) (Eric Ma)

### Deprecations

No deprecations were made in this version.
